#!/bin/sh
SCRIPT_VERSION='1.2.0-eva2000.03'
SCRIPT_DATE='11/06/2011'
SCRIPT_AUTHOR='BTCentral (btcentral.org.uk)'
SCRIPT_MODIFICATION_AUTHOR='eva2000 (vbtechsupport.com)'
COPYRIGHT="Copyright 2011 BTCentral"
DISCLAIMER='This software is provided "as is" in the hope that it will be useful, but WITHOUT ANY WARRANTY, to the extent permitted by law; without even the implied warranty of MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.'
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version. See the included license.txt for futher details.
#
# PLEASE MODIFY VALUES BELOW THIS LINE ++++++++++++++++++++++++++++++++++++++
# Note: Please enter y for yes or n for no.

# General Configuration
ZONEINFO=Australia/Brisbane  # Set Timezone
NSD_INSTALL=y                # Install NSD (DNS Server)
NSD_VERSION='3.2.8'          # NSD Version
NTP_INSTALL=y                # Install Network time protocol daemon
NGINX_INSTALL=y              # Install Nginx (Webserver)
PHP_INSTALL=y                # Install PHP /w Fast Process Manager
MDB_INSTALL=y                # Install MariaDB MySQL Server replacement (Not recommended for VPS with less than 512MB RAM!)
MDB_VERSION='5.2.6-101'      # Use this version of MariaDB 5.2.6
# Optionally, if you want to install MariaDB instead of standard MySQL you can do. 
# Set MDB_INSTALL=y and MYSQL_INSTALL=n
MYSQL_INSTALL=n              # Install MySQL Server (MariaDB recommended)
SENDMAIL_INSTALL=y           # Install Sendmail (and mailx)
# Nginx
NGINX_VERSION='1.0.4'        # Use this version of Nginx
LIBUNWIND_VERSION='0.99'     # Use this version of libunwind
GPERFTOOLS_VERSION='1.7'     # Use this version of google-perftools
OPENSSL_VERSION='1.0.0d'     # Use this version of OpenSSL
LIBEVENT_VERSION='2.0.10'    # Use this version of Libevent
MEMCACHED_VERSION='1.4.5'    # Use this version of Memcached
MEMCACHE_VERSION='3.0.5'     # Use this version of Memcache - note issues with 3.0.6
PYTHON_VERSION='2.7.1'       # Use this version of Python
PCRE_VERSION='8.12'          # Use this version of PCRE library
# PHP and Cache/Acceleration
PHP_VERSION='5.3.6'          # Use this version of PHP
XCACHE_VERSION='1.3.2'       # Use this version of Xcache
APCCACHE_VERSION='3.1.9'       # Use this version of APC Cache

# The default is stable, you can change this to development if you wish
#ARCH_OVERRIDE='i386'
# Uncomment the above line if you are running a 32bit Paravirtulized Xen VPS
# on a 64bit host node.

# YOU SHOULD NOT NEED TO MODIFY ANYTHING BELOW THIS LINE  +++++++++++++++++++
# JUST RUN chmod +x ./centmin.sh && ./centmin.sh
#
###############################################################
KEYPRESS_PARAM='-s -n1 -p'   # Read a keypress without hitting ENTER.
		# -s means do not echo input.
		# -n means accept only N characters of input.
		# -p means echo the following prompt before reading input
ASKCMD="read $KEYPRESS_PARAM "
MACHINE_TYPE=`uname -m` # Used to detect if OS is 64bit or not.
CUR_DIR=`pwd` # Get current directory.
###############################################################
# FUNCTIONS

if [ "${ARCH_OVERRIDE}" != '' ]
then
    ARCH=${ARCH_OVERRIDE}
else
    if [ ${MACHINE_TYPE} == 'x86_64' ];
    then
        ARCH='x86_64'
    else
        ARCH='i386'
    fi
fi

ASK () {
keystroke=''
while [[ "$keystroke" != [yYnN] ]]
do
    $ASKCMD "$1" keystroke
    echo "$keystroke";
done

key=$(echo $keystroke)
}

# Setup Colours
black='\E[30;40m'
red='\E[31;40m'
green='\E[32;40m'
yellow='\E[33;40m'
blue='\E[34;40m'
magenta='\E[35;40m'
cyan='\E[36;40m'
white='\E[37;40m'

boldblack='\E[1;30;40m'
boldred='\E[1;31;40m'
boldgreen='\E[1;32;40m'
boldyellow='\E[1;33;40m'
boldblue='\E[1;34;40m'
boldmagenta='\E[1;35;40m'
boldcyan='\E[1;36;40m'
boldwhite='\E[1;37;40m'

Reset="tput sgr0"      #  Reset text attributes to normal
                       #+ without clearing screen.

cecho ()                     # Coloured-echo.
                             # Argument $1 = message
                             # Argument $2 = color
{
message=$1
color=$2
echo -e "$color$message" ; $Reset
return
}

run_once ()
{
# If OpenVZ user add user/group 500 - else various folders and devices will end up with an odd user/group name for some reason
if [ -f /proc/user_beancounters ];
then
    groupadd 500
    useradd -g 500 -s /sbin/nologin -M 500
fi

ASK "Would you like to update any pre-installed software? (Recommended) [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "Let's do that then..."
    yum clean all
    yum -y update glibc\*
    yum -y update yum\* rpm\* python\*
    yum clean all
    yum -y update
fi

if [ ${ARCH} == 'x86_64' ];
then
    ASK "Would you like to exclude installation of 32bit Yum packages? (Recommended for 64bit CentOS) [y/n] "
    if [[ "$key" = [yY] ]];
    then
        mv /etc/yum.conf /etc/yum.bak
        mv $CUR_DIR/config/yum/yum.conf /etc/yum.conf
        echo "Your origional yum configuration has been backed up to /etc/yum.bak"
    else
        rm -rf $CUR_DIR/config/yum
    fi
fi

ASK "Would you like to secure /tmp and /var/tmp? (Highly recommended) [y/n] "   
if [[ "$key" = [yY] ]]; 
then
	echo "*************************************************"
	cecho "* Secured /tmp and /var/tmp" $boldgreen
	echo "*************************************************"

	rm -rf /tmp
	mkdir /tmp
	mount -t tmpfs -o rw,noexec,nosuid tmpfs /tmp
	chmod 1777 /tmp
	echo "tmpfs   /tmp    tmpfs   rw,noexec,nosuid        0       0" >> /etc/fstab
	rm -rf /var/tmp
	ln -s /tmp /var/tmp
fi

echo "*************************************************"
cecho "* Installing Development Tools" $boldgreen
echo "*************************************************"
    yum -y install gcc gcc-c++ automake autoconf autoconf213 libtool make libXext-devel unzip distcache slocate patch sysstat gcc44 gcc44-c++ zlib zlib-devel openssh* openssl* gd gd-devel pcre pcre-devel pcre.${ARCH} pcre-devel.${ARCH} flex bison file libgcj gettext gettext-devel e2fsprogs-devel libtool-libs libtool-ltdl-devel kernel-devel libidn libidn-devel krb5-devel libjpeg libjpeg-devel libpng libpng-devel freetype freetype-devel libxml2 libxml2-devel libXpm-devel libmcrypt libmcrypt-devel glib2 glib2-devel bzip2 bzip2-devel vim-minimal nano sendmail ncurses ncurses-devel curl curl-devel e2fsprogs gmp-devel pspell-devel aspell-devel numactl lsof pkgconfig gdbm-devel tk-devel bluez-libs-devel iptables* rrdtool

ASK "Would you like to set the server localtime? [y/n] "   
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Setting preferred localtime for VPS" $boldgreen
    echo "*************************************************"
    rm -f /etc/localtime
    ln -s /usr/share/zoneinfo/$ZONEINFO /etc/localtime
    echo "Current date & time for the zone you selected is:"
    date
fi
}

# END FUNCTIONS
################################################################
# SCRIPT START
#
clear
cecho "**********************************************************************" $boldyellow
cecho "* Centmin, an nginx, MariaDB/MySQL, PHP & DNS Install script for CentOS" $boldgreen
cecho "* Version: $SCRIPT_VERSION - Date: $SCRIPT_DATE - $COPYRIGHT" $boldgreen
cecho "* Contributions by: $SCRIPT_MODIFICATION_AUTHOR" $boldgreen
cecho "**********************************************************************" $boldyellow
echo " "
cecho "This software comes with no warranty of any kind. You are free to use" $boldyellow
cecho "it for both personal and commercial use as licensed under the GPL." $boldyellow
echo " "
cecho "Please read the included readme.txt before using this script." $boldmagenta
echo " "
ASK "Would you like to continue? [y/n] "   
if [[ "$key" = [nN] ]];
then
    exit 0
fi

# Set LIBDIR
if [ ${ARCH} == 'x86_64' ];
then
    LIBDIR='lib64'
else
    LIBDIR='lib'
fi

DIR_TMP="/svr-setup"
if [ -a "$DIR_TMP" ];
then
	ASK "It seems that you have run this script before, would you like to start from after setting the timezone? [y/n] "
	if [[ "$key" = [nN] ]];
	then
		run_once
	fi
else
	mkdir /svr-setup
	run_once
fi

if [[ "$NSD_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing NSD" $boldgreen
    echo "*************************************************"
    cd /svr-setup
    if [ -s nsd-${NSD_VERSION}.tar.gz ]; then
        cecho "NSD ${NSD_VERSION} Archive found, skipping download..." $boldgreen 
    else
        wget -c http://www.nlnetlabs.nl/downloads/nsd/nsd-${NSD_VERSION}.tar.gz
    fi
    echo "Compiling NSD..."
    tar xzvf nsd-${NSD_VERSION}.tar.gz
    cd nsd-${NSD_VERSION}
    ./configure
    make
    make install
    echo "Creating user and group for nsd..."
    groupadd nsd
    useradd -g nsd -s /sbin/nologin -M nsd
    echo "Setting up directories..."
    mkdir /var/run/nsd
    chown -R nsd:nsd /var/run/nsd/
    chown -R nsd:nsd /var/db/nsd/
    mkdir /etc/nsd/master
    mkdir /etc/nsd/slave
    chown -R nsd:nsd /etc/nsd/
    cp -R $CUR_DIR/config/nsd/* /etc/nsd/
    cd /etc/sysconfig/
    mv $CUR_DIR/sysconfig/nsd nsd
    cd /etc/init.d/
    mv $CUR_DIR/init/nsd nsd
    chmod +x /etc/init.d/nsd
    chkconfig --levels 235 nsd on
    echo "*************************************************"
    cecho "* NSD installed" $boldgreen
    echo "*************************************************"
fi

if [ -f /proc/user_beancounters ];
then
    cecho "OpenVZ system detected, NTP not installed" $boldgreen
else
    if [[ "$NTP_INSTALL" = [yY] ]]; 
    then
        echo "*************************************************"
        cecho "* Installing NTP (and syncing time)" $boldgreen
        echo "*************************************************"
        yum -y install ntp
        chkconfig --levels 235 ntpd on
        ntpdate pool.ntp.org
        echo "The date/time is now:"
        date
        echo "If this is correct, then everything is working properly"
        echo "*************************************************"
        cecho "* NTP installed" $boldgreen
        echo "*************************************************"
    fi
fi

if [[ "$NGINX_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing nginx" $boldgreen
    echo "*************************************************"

    # Disable Apache if installed
    if [ -f /etc/init.d/httpd ];
    then
      /sbin/service httpd stop
      chkconfig httpd off
    fi

    # Then install nginx
    cd /svr-setup

    # Set VPS hard/soft limits
    echo "* soft nofile 65536" >>/etc/security/limits.conf
    echo "* hard nofile 65536" >>/etc/security/limits.conf

    # nginx Modules / Prerequisites
	cecho "Installing nginx Modules / Prerequisites..." $boldgreen

    # Install libunwind
    echo "Compiling libunwind..."
    if [ -s libunwind-${LIBUNWIND_VERSION}.tar.gz ]; then
        cecho "libunwind ${LIBUNWIND_VERSION} Archive found, skipping download..." $boldgreen 
    else
        wget -c http://download.savannah.gnu.org/releases/libunwind/libunwind-${LIBUNWIND_VERSION}.tar.gz
    fi

    tar xvzf libunwind-${LIBUNWIND_VERSION}.tar.gz
    cd libunwind-${LIBUNWIND_VERSION}
    ./configure
    make
    make install

    # Install google-perftools
    cd /svr-setup

    echo "Compiling google-perftools..."
    if [ -s google-perftools-${GPERFTOOLS_VERSION}.tar.gz ]; then
        cecho "google-perftools ${GPERFTOOLS_VERSION} Archive found, skipping download..." $boldgreen
    else
        wget -c http://google-perftools.googlecode.com/files/google-perftools-${GPERFTOOLS_VERSION}.tar.gz
    fi

    tar xvzf google-perftools-${GPERFTOOLS_VERSION}.tar.gz
    cd google-perftools-${GPERFTOOLS_VERSION}
    ./configure --enable-frame-pointers
    make
    make install
    echo "/usr/local/lib" > /etc/ld.so.conf.d/usr_local_lib.conf
    /sbin/ldconfig

    # Install OpenSSL
    cd /svr-setup

    echo "Compiling OpenSSL..."
    if [ -s openssl-${OPENSSL_VERSION}.tar.gz ]; then
        cecho "openssl ${OPENSSL_VERSION} Archive found, skipping download..." $boldgreen
    else
        wget -c http://www.openssl.org/source/openssl-${OPENSSL_VERSION}.tar.gz
    fi

    tar xvzf openssl-${OPENSSL_VERSION}.tar.gz
    cd openssl-${OPENSSL_VERSION}
    ./config --prefix=/usr/local --openssldir=/usr/local/ssl
    make
    make install

    ./config shared --prefix=/usr/local --openssldir=/usr/local/ssl
    make clean
    make
    make install

    # Install PCRE
    cd /svr-setup

    echo "Compiling PCRE..."
    if [ -s pcre-${PCRE_VERSION}.tar.gz ]; then
        cecho "pcre ${PCRE_VERSION} Archive found, skipping download..." $boldgreen
    else
        wget -c ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre-${PCRE_VERSION}.tar.gz
    fi

    tar xvzf pcre-${PCRE_VERSION}.tar.gz
    cd pcre-${PCRE_VERSION}
    ./configure
    make
    make install

    # nginx Modules
    cd /svr-setup

    if [ -s ngx-fancyindex-0.3.1.tar.gz ]; then
        cecho "ngx-fancyindex 0.3.1 Archive found, skipping download..." $boldgreen
    else
        wget -c http://gitorious.org/ngx-fancyindex/ngx-fancyindex/archive-tarball/v0.3.1
    fi

mv v0.3.1 ngx-fancyindex-0.3.1.tar.gz

    tar zvxf ngx-fancyindex-0.3.1.tar.gz

    if [ -s ngx_cache_purge-1.3.tar.gz ]; then
        cecho "ngx_cache_purge 1.3 Archive found, skipping download..." $boldgreen
    else
        wget -c http://labs.frickle.com/files/ngx_cache_purge-1.3.tar.gz
    fi

    tar zvxf ngx_cache_purge-1.3.tar.gz

    if [ -s Nginx-accesskey-2.0.3.tar.gz ]; then
        cecho "Nginx-accesskey 2.0.3 Archive found, skipping download..." $boldgreen
    else
        wget -c http://wiki.nginx.org/images/5/51/Nginx-accesskey-2.0.3.tar.gz
    fi

    tar zvxf Nginx-accesskey-2.0.3.tar.gz

    # Install nginx
    cd /svr-setup

    echo "Compiling nginx..."
    if [ -s nginx-${NGINX_VERSION}.tar.gz ]; then
        cecho "nginx ${NGINX_VERSION} Archive found, skipping download..." $boldgreen
    else
        wget -c "http://nginx.org/download/nginx-${NGINX_VERSION}.tar.gz"
    fi

    tar xvfz nginx-${NGINX_VERSION}.tar.gz
    cd nginx-${NGINX_VERSION}

    ASK "Would you like to compile nginx with IPv6 support? [y/n] "
    if [[ "$key" = [yY] ]];
    then
        ./configure --with-cc-opt='-O3' --sbin-path=/usr/local/sbin --conf-path=/usr/local/nginx/conf/nginx.conf --with-ipv6 --with-http_ssl_module --with-http_gzip_static_module --with-http_stub_status_module --with-http_sub_module --with-http_addition_module --with-http_secure_link_module --with-http_flv_module --with-http_realip_module --add-module=../ngx-fancyindex-ngx-fancyindex --add-module=../ngx_cache_purge-1.3 --add-module=../nginx-accesskey-2.0.3 --with-google_perftools_module --with-openssl=../openssl-1.0.0d --with-ld-opt='-ltcmalloc_minimal'
    else
        ./configure --with-cc-opt='-O3' --sbin-path=/usr/local/sbin --conf-path=/usr/local/nginx/conf/nginx.conf --with-http_ssl_module --with-http_gzip_static_module --with-http_stub_status_module --with-http_sub_module --with-http_addition_module --with-http_secure_link_module --with-http_flv_module --with-http_realip_module --add-module=../ngx-fancyindex-ngx-fancyindex --add-module=../ngx_cache_purge-1.3 --add-module=../nginx-accesskey-2.0.3 --with-google_perftools_module --with-openssl=../openssl-1.0.0d --with-ld-opt='-ltcmalloc_minimal'
    fi    

    make
    make install

    groupadd nginx
    useradd -g nginx -d /home/nginx -s /sbin/nologin nginx
    # Set user nginx hard/soft limits
    echo "nginx soft nofile 65536" >>/etc/security/limits.conf
    echo "nginx hard nofile 65536" >>/etc/security/limits.conf
    ulimit -n 65536

    mkdir /home/nginx/domains
    mkdir -p /home/nginx/domains/demo.com/{public,private,log,backup}
    cp -R $CUR_DIR/htdocs/demo.com/* /home/nginx/domains/demo.com/public
    chown -R nginx:nginx /home/nginx

    mkdir -p /usr/local/nginx/html
    mkdir -p /usr/local/nginx/conf/conf.d
    cp -R $CUR_DIR/htdocs/default/* /usr/local/nginx/html
    #rm -rf $CUR_DIR/htdocs
    cp -R $CUR_DIR/config/nginx/* /usr/local/nginx/conf
    mv $CUR_DIR/init/nginx /etc/init.d/nginx
    chmod +x /etc/init.d/nginx
    chkconfig --levels 235 nginx on

# rackspace cloud servers block port 80 so need to allow it
iptables -I RH-Firewall-1-INPUT -p tcp --dport 80 -j ACCEPT
    echo "*************************************************"
    cecho "* nginx installed, Apache disabled" $boldgreen
    echo "*************************************************"
fi

if [[ "$MDB_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing MariaDB " $boldgreen
    echo "*************************************************"
    yum -y remove mysql
    cp -a /etc/my.cnf /etc/my.cnf-original
    cp -R $CUR_DIR/config/mysql/my-mdb.cnf /etc/my.cnf

    # The MariaDB mirror uses x86 and amd64 prefixes for rpm folders instead of i386/x84_64, so compensate for that...
    if [ ${ARCH} == 'x86_64' ];
    then
        MDB_ARCH='amd64'
    else
        MDB_ARCH='x86'
    fi

    cd /svr-setup

    if [ -s MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        wget -c http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-5.2.6/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm
    fi

    if [ -s MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        wget -c http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-5.2.6/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm
    fi

    if [ -s MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        wget -c http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-5.2.6/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm
    fi

    if [ -s MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        wget -c http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-5.2.6/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm
    fi

    if [ -s MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        wget -c http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-5.2.6/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm
    fi

    rpm -i MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm

    yum -y install perl-DBD-MySQL

    cd /root

    if [ -s mysqlreport ]; then
        cecho "mysqlreport found, skipping download..." $boldgreen
    else
        wget -c http://thisfile.net/mysqlreport
    fi

    if [ -s mysqltuner.pl ]; then
        cecho "mysqltuner.pl found, skipping download..." $boldgreen
    else
        wget -c http://vbtechsupport.com/mysqltuner/mysqltuner.txt
    fi

	mv mysqltuner.txt mysqltuner.pl

    chmod +x mysqlreport mysqltuner.pl

    cd /svr-setup

    chkconfig --levels 235 mysql on
    /etc/init.d/mysql start

if [[ ! `grep exclude /etc/yum.conf` ]]; then

cecho "Can't find exclude line in /etc/yum.conf... adding exclude line for mysql*" $boldgreen

echo "exclude=mysql*">> /etc/yum.conf

else

cecho "exclude line exists... adding exclude line for mysql*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686/exclude=\*.i386 \*.i586 \*.i686 mysql\*/" /etc/yum.conf

fi

    echo "*************************************************"
    cecho "* Starting MariaDB Secure Installation" $boldgreen
    echo "*************************************************"
    mysql_secure_installation
    echo "*************************************************"
    cecho "* MariaDB installed" $boldgreen
    echo "*************************************************"
    
    /etc/init.d/mysql stop
fi

if [[ "$MYSQL_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing MySQL" $boldgreen
    echo "*************************************************"
    yum -y install mysql mysql-devel mysql-server perl-DBD-MySQL

    cp -a /etc/my.cnf /etc/my.cnf-original
    cp -R $CUR_DIR/config/mysql/my.cnf /etc/my.cnf

    cd /root

    if [ -s mysqlreport ]; then
        cecho "mysqlreport found, skipping download..." $boldgreen
    else
        wget -c http://thisfile.net/mysqlreport
    fi

    if [ -s mysqltuner.pl ]; then
        cecho "mysqltuner.pl found, skipping download..." $boldgreen
    else
        wget -c http://vbtechsupport.com/mysqltuner/mysqltuner.txt
    fi

	mv mysqltuner.txt mysqltuner.pl

    chmod +x mysqlreport mysqltuner.pl

    cd /svr-setup

    chkconfig --levels 235 mysqld on
    /etc/init.d/mysqld start

    echo "*************************************************"
    cecho "* Starting MySQL Secure Installation" $boldgreen
    echo "*************************************************"
    mysql_secure_installation
    echo "*************************************************"
    cecho "* MySQL installed" $boldgreen
    echo "*************************************************"

    /etc/init.d/mysqld stop
fi

if [[ "$PHP_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing PHP" $boldgreen
    echo "*************************************************"

    export PHP_AUTOCONF=/usr/bin/autoconf-2.13
    export PHP_AUTOHEADER=/usr/bin/autoheader-2.13

    cd /svr-setup

    # IMPORTANT Erase any PHP installations first, otherwise conflicts may arise
    yum -y erase php*

    if [ -s php-${PHP_VERSION}.tar.gz ]; then
        cecho "php ${PHP_VERSION} Archive found, skipping download..." $boldgreen
    else
        wget -c http://us2.php.net/get/php-${PHP_VERSION}.tar.gz/from/this/mirror
    fi

    tar xzvf php-${PHP_VERSION}.tar.gz

    cd php-${PHP_VERSION}

    ./buildconf --force
    mkdir fpm-build && cd fpm-build

    mkdir -p /usr/${LIBDIR}/mysql
    ln -s /usr/${LIBDIR}/libmysqlclient.so /usr/${LIBDIR}/mysql/libmysqlclient.so

../configure --enable-cgi --enable-fpm --with-mhash --with-zlib --with-gettext --enable-exif --enable-zip --with-bz2 --enable-soap --enable-sockets --enable-sysvmsg --enable-sysvsem --enable-sysvshm --enable-shmop --with-pear --enable-mbstring --with-openssl --with-mysql=/usr/bin/ --with-libdir=${LIBDIR} --with-mysqli=/usr/bin/mysql_config --with-mysql-sock --with-curl --with-gd --with-xmlrpc --enable-bcmath --enable-calendar --enable-ftp --enable-gd-native-ttf --without-sqlite --disable-pdo --with-fpm-user=nginx --with-fpm-group=nginx

    make
    make install

    cd ../
    cp -f php.ini-production /usr/local/lib/php.ini
    chmod 644 /usr/local/lib/php.ini

    sed -i "s/;date.timezone =/date.timezone = Australia\/Brisbane/g" /usr/local/lib/php.ini

    sed -i 's/short_open_tag = Off/short_open_tag = On/g' /usr/local/lib/php.ini
    sed -i 's/;realpath_cache_size = 16k/realpath_cache_size = 1024k/g' /usr/local/lib/php.ini
    sed -i 's/;realpath_cache_ttl = 120/realpath_cache_ttl = 180/g' /usr/local/lib/php.ini
    sed -i 's/upload_max_filesize = 2M/upload_max_filesize = 15M/g' /usr/local/lib/php.ini
    #sed -i 's/memory_limit = 128M/memory_limit = 256M/g' /usr/local/lib/php.ini
    sed -i 's/post_max_size = 8M/post_max_size = 15M/g' /usr/local/lib/php.ini

    cp $CUR_DIR/config/php-fpm/php-fpm.conf /usr/local/etc/php-fpm.conf
    cp $CUR_DIR/init/php-fpm /etc/init.d/php-fpm

    chmod +x /etc/init.d/php-fpm

    mkdir -p /var/run/php-fpm
    touch /var/run/php-fpm/php-fpm.pid
    chown nginx:nginx /var/run/php-fpm

    mkdir /var/log/php-fpm/
    touch /var/log/php-fpm/www-error.log
    chmod 0666 /var/log/php-fpm/www-error.log

    #chown -R root:nginx /var/lib/php/session/
    chkconfig --levels 235 php-fpm on
    /etc/init.d/php-fpm start

if [[ `grep exclude /etc/yum.conf` && $MDB_INSTALL = y ]]; then

cecho "exclude line exists... adding mysql* php*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686 mysql\*/exclude=\*.i386 \*.i586 \*.i686 mysql\* php\*/" /etc/yum.conf

sed -i "s/exclude=mysql\*/exclude=mysql\* php\*/" /etc/yum.conf

elif [[ `grep exclude /etc/yum.conf` ]]; then

cecho "exclude line exists... adding php*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686/exclude=\*.i386 \*.i586 \*.i686 php\*/" /etc/yum.conf 

fi


if [[ ! `grep exclude /etc/yum.conf` && $MDB_INSTALL = y ]]; then

cecho "Can't find exclude line in /etc/yum.conf.. adding exclude line for mysql* php*" $boldgreen

echo "exclude=mysql* php*">> /etc/yum.conf

elif [[ ! `grep exclude /etc/yum.conf` ]]; then

cecho "Can't find exclude line in /etc/yum.conf... adding exclude line for php*" $boldgreen

echo "exclude=php*">> /etc/yum.conf

fi

    echo "*************************************************"
    cecho "* PHP installed" $boldgreen
    echo "*************************************************"
fi

ASK "Install XCache? (By default uses 32MB RAM) If XCache installed DO NOT install APC [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing XCache" $boldgreen
    echo "*************************************************"

    cd /svr-setup

    if [ -s xcache-${XCACHE_VERSION}.tar.gz ]; then
        cecho "xcache ${XCACHE_VERSION} Archive found, skipping download..." $boldgreen
    else
        wget -c http://xcache.lighttpd.net/pub/Releases/${XCACHE_VERSION}/xcache-${XCACHE_VERSION}.tar.gz
    fi

    cat $CUR_DIR/config/xcache/xcache.ini >> /usr/local/lib/php.ini

    export PHP_AUTOCONF=/usr/bin/autoconf
    export PHP_AUTOHEADER=/usr/bin/autoheader

    tar xvfz xcache-${XCACHE_VERSION}.tar.gz
    cd xcache-${XCACHE_VERSION}
    /usr/local/bin/phpize
    ./configure --enable-xcache --with-php-config=/usr/local/bin/php-config
    make && make install

if [ ! -d /usr/local/nginx/html/myxcacheadmin ]; then

    echo ""
    cecho "Creating xcache admin directory at /usr/local/nginx/html/myxcacheadmin " $boldgreen

mkdir /usr/local/nginx/html/myxcacheadmin
fi

cp -a admin/* /usr/local/nginx/html/myxcacheadmin
chown -R nginx:nginx /usr/local/nginx/html/myxcacheadmin

    echo ""
    echo "*************************************************"
    cecho "Setup Xcache Admin Password for /usr/local/nginx/html/myxcacheadmin" $boldgreen
    echo "*************************************************"
    echo -n "(Type password your want to set and press Enter): "
read xcachepassword

xcachepass="`echo -n "${xcachepassword}" | md5sum | awk '{ print $1 }'`"

cecho "old password: `grep xcache.admin.pass /usr/local/lib/php.ini | awk '{ print $3 }' | sed -e 's/"//g'`" $boldgreen
cecho "new password: ${xcachepass}" $boldgreen
cecho "xcache username: `grep xcache.admin.user /usr/local/lib/php.ini | awk '{ print $3 }' | sed -e 's/"//g'`" $boldgreen

    sed -i "s/d440aed189a13ff970dac7e7e8f987b2/${xcachepass}/g" /usr/local/lib/php.ini

cecho "php.ini now has xcache.admin.pass set as follows: :" $boldgreen
cecho "`cat /usr/local/lib/php.ini | grep xcache.admin.pass`" $boldgreen

    /etc/init.d/php-fpm restart
    echo "*************************************************"
    cecho "* XCache installed" $boldgreen
    echo "*************************************************"
fi

    cecho "* If you installed Xcache, DO NOT install APC" $boldgreen

ASK "Install APC? (By default uses 32MB RAM) [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing Alternative PHP Cache" $boldgreen
    echo "*************************************************"

    cd /svr-setup

    if [ -s APC-${APCCACHE_VERSION}.tgz ]; then
        cecho "xcache APC-${APCCACHE_VERSION}.tgz Archive found, skipping download..." $boldgreen
    else
        wget -c http://pecl.php.net/get/APC-${APCCACHE_VERSION}.tgz
    fi

    export PHP_AUTOCONF=/usr/bin/autoconf
    export PHP_AUTOHEADER=/usr/bin/autoheader

tar xvzf APC-${APCCACHE_VERSION}.tgz
cd APC-${APCCACHE_VERSION}
/usr/local/bin/phpize
./configure --with-php-config=/usr/local/bin/php-config
make
make install

cp apc.php /usr/local/nginx/html/myapc.php
chown nginx:nginx /usr/local/nginx/html/myapc.php

cat $CUR_DIR/config/apc/apc.ini >> /usr/local/lib/php.ini

    /etc/init.d/php-fpm restart
    echo "*************************************************"
    cecho "* Alternative PHP Cache installed" $boldgreen
    echo "*************************************************"
fi

if [[ "$SENDMAIL_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing sendmail" $boldgreen
    echo "*************************************************"
    yum -y install sendmail mailx
    chkconfig --levels 235 sendmail on
    /etc/init.d/sendmail start
    echo "*************************************************"
    cecho "* sendmail installed" $boldgreen
    echo "*************************************************"
fi

ASK "Install Memcached Server? (default uses 16MB RAM each) [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing memcached" $boldgreen
    echo "*************************************************"
    echo "Downloading memcached..."
    cd /svr-setup

if [ -s libevent-${LIBEVENT_VERSION}-stable.tar.gz ]; then
  cecho "libevent-${LIBEVENT_VERSION}-stable.tar.gz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: libevent-${LIBEVENT_VERSION}-stable.tar.gz not found!!!download now......"
  wget -c http://www.monkey.org/~provos/libevent-${LIBEVENT_VERSION}-stable.tar.gz
fi

if [ -s memcached-${MEMCACHED_VERSION}.tar.gz ]; then
  cecho "memcached-${MEMCACHED_VERSION}.tar.gz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: memcached-${MEMCACHED_VERSION}.tar.gz not found!!!download now......"
  wget -c http://memcached.googlecode.com/files/memcached-${MEMCACHED_VERSION}.tar.gz
fi

if [ -s memcache-${MEMCACHE_VERSION}.tgz ]; then
  cecho "memcache-${MEMCACHE_VERSION}.tgz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: memcache-2.2.5.tgz not found!!!download now......"
  wget -c http://pecl.php.net/get/memcache-${MEMCACHE_VERSION}.tgz
fi

    cecho "Compiling libevent..." $boldgreen

cd /svr-setup
tar xfz libevent-${LIBEVENT_VERSION}-stable.tar.gz
cd libevent-${LIBEVENT_VERSION}-stable
./configure --prefix=/usr/${LIBDIR}
make && make install

echo "/usr/${LIBDIR}/lib/" > /etc/ld.so.conf.d/libevent-i386.conf
ldconfig

    cecho "Compiling memcached..." $boldgreen

cd /svr-setup
tar xzf memcached-${MEMCACHED_VERSION}.tar.gz
cd memcached-${MEMCACHED_VERSION}
./configure --with-libevent=/usr/${LIBDIR}
make && make install
cp /svr-setup/memcached-${MEMCACHED_VERSION}/scripts/memcached-tool /usr/local/bin

    cecho "Compiling memcached..." $boldgreen

cd /svr-setup
cp $CUR_DIR/config/memcached/memcached /etc/init.d/memcached
chmod +x /etc/init.d/memcached
chkconfig --add memcached
chkconfig --level 345 memcached on
service memcached start

    cecho "Compiling PHP memcache extension..." $boldgreen

cd /svr-setup
tar -xvf memcache-${MEMCACHE_VERSION}.tgz
cd memcache-${MEMCACHE_VERSION}
/usr/local/bin/phpize
./configure --enable-memcache --with-php-config=/usr/local/bin/php-config
make && make install
echo "extension=/usr/local/lib/php/extensions/no-debug-non-zts-20090626/memcache.so" >> /usr/local/lib/php.ini

/etc/init.d/php-fpm restart

    echo ""
    echo "*************************************************"
    cecho "Setup memcached.php admin page ..." $boldgreen
    echo "*************************************************"

cp -a memcache.php /usr/local/nginx/html
chown -R nginx:nginx /usr/local/nginx/html
chmod 644 /usr/local/nginx/html/memcache.php

sed -i "s/'ADMIN_USERNAME','memcache'/'ADMIN_USERNAME','memcacheuser'/g" /usr/local/nginx/html/memcache.php
sed -i "s/'ADMIN_PASSWORD','password'/'ADMIN_PASSWORD','memcachepass'/g" /usr/local/nginx/html/memcache.php
sed -i "s/mymemcache-server1:11211/localhost:11211/g" /usr/local/nginx/html/memcache.php
sed -i "s/mymemcache-server2:11211/localhost:11212/g" /usr/local/nginx/html/memcache.php

cecho "Setup Memcached Server Admin Login Details for /usr/local/nginx/html/memcache.php" $boldgreen
echo -n "(Type username your want to set and press Enter): "
read memcacheduser
echo -n "(Type password your want to set and press Enter): "
read memcachedpassword

cecho "current memcached username: `grep "'ADMIN_USERNAME','memcacheuser'" /usr/local/nginx/html/memcache.php | sed -e "s/define('ADMIN_USERNAME','//" | sed -e 's/\/\/ Admin Username//' | sed 's/^[ \t]*//;s/[ \t]*$//' | sed -e "s/');//"`" $boldgreen

cecho "current memcached password: `grep "'ADMIN_PASSWORD','memcachepass'" /usr/local/nginx/html/memcache.php | sed -e "s/define('ADMIN_PASSWORD','//" | sed -e 's/\/\/ Admin Password//' | sed 's/^[ \t]*//;s/[ \t]*$//' | sed -e "s/');//"`" $boldgreen

sed -i "s/'ADMIN_USERNAME','memcacheuser'/'ADMIN_USERNAME','${memcacheduser}'/g" /usr/local/nginx/html/memcache.php
sed -i "s/'ADMIN_PASSWORD','memcachepass'/'ADMIN_PASSWORD','${memcachedpassword}'/g" /usr/local/nginx/html/memcache.php

cecho "new memcached username: ${memcacheduser}" $boldgreen
cecho "new memcached password: ${memcachedpassword}" $boldgreen

    echo "*************************************************"
    cecho "* memcached installed" $boldgreen
    echo "*************************************************"
fi
ASK "Install CSF firewall script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing CSF firewall... " $boldgreen
    echo "*************************************************"
    echo "Installing..."

    cd /svr-setup

    if [ -s csf.tgz ]; then
        cecho "csf Archive found, skipping download..." $boldgreen
    else
        wget -c http://www.configserver.com/free/csf.tgz
    fi

    yum -y install perl-libwww-perl

    tar xzf csf.tgz
    cd csf
    sh install.sh

    echo "Test IP Tables Modules..."

    perl /etc/csf/csftest.pl

    echo "CSF adding memcached, varnish ports to csf.allow list..."
    sed -i 's/20,21,22,25,53,80,110,143,443,465,587,993,995/20,21,22,25,53,80,110,143,161,443,465,587,993,995,1186,2202,11211,11212,11213,11214,2222,3334,8080,8888,81,9000,9001,6081,6082,3000:3050/g' /etc/csf/csf.conf
    
    echo "Disabling CSF Testing mode (activates firewall)..."
    sed -i 's/TESTING = "1"/TESTING = "0"/g' /etc/csf/csf.conf

    echo "Adding Applications/Users to CSF ignore list..."
cat >>/etc/csf/csf.pignore<<EOF
exe:/usr/local/bin/memcached
cmd:/usr/local/bin/memcached
user:mysql
exe:/usr/sbin/mysqld 
cmd:/usr/sbin/mysqld
user:varnish
exe:/usr/sbin/varnishd
cmd:/usr/sbin/varnishd
exe:/sbin/portmap
cmd:portmap
exe:/usr/libexec/gdmgreeter
cmd:/usr/libexec/gdmgreeter
exe:/usr/sbin/avahi-daemon
cmd:avahi-daemon
exe:/sbin/rpc.statd
cmd:rpc.statd
exe:/usr/libexec/hald-addon-acpi
cmd:hald-addon-acpi
user:nsd
user:nginx
user:ntp
user:dbus
user:smmsp
user:postfix
user:dovecot
user:www-data
user:spamfilter
EOF

    chkconfig --levels 235 csf on
    service csf restart

    echo "*************************************************"
    cecho "* CSF firewall installed " $boldgreen
    echo "*************************************************"
fi

ASK "Install Siege Benchmark script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing Siege Benchmark... " $boldgreen
    echo "*************************************************"
    echo "Installing..."

    cd /svr-setup

    if [ -s siege-latest.tar.gz ]; then
        cecho "siege-latest Archive found, skipping download..." $boldgreen
    else
        wget -c ftp://ftp.joedog.org/pub/siege/siege-latest.tar.gz
    fi

    if [ -s sproxy-latest.tar.gz ]; then
        cecho "sproxy-latest Archive found, skipping download..." $boldgreen
    else
        wget -c ftp://ftp.joedog.org/pub/sproxy/sproxy-latest.tar.gz
    fi

    tar -xzf siege-latest.tar.gz
    cd siege-2.70
    ./configure
    make
    make install
    mkdir /usr/local/var/

    sed -i 's/# failures =/failures = 2048/g' /usr/local/etc/siegerc

    cd /svr-setup

    tar -xzf sproxy-latest.tar.gz
    cd sproxy-1.01
    ./configure
    make
    make install

    echo "*************************************************"
    cecho "* Siege Benchmark installed " $boldgreen
    echo "*************************************************"
fi

ASK "Install Python Update ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing Python... " $boldgreen
    echo "*************************************************"
    echo "Installing..."

cd /svr-setup

if [ -s Python-${PYTHON_VERSION}.tgz ]; then
  cecho "Python-${PYTHON_VERSION}.tgz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: Python-${PYTHON_VERSION}.tgz not found!!!download now......"
  wget -c http://www.python.org/ftp/python/${PYTHON_VERSION}/Python-${PYTHON_VERSION}.tgz
fi

if [ -s setuptools-0.6c11-py2.7.egg ]; then
  cecho "setuptools-0.6c11-py2.7.egg Archive found, skipping download..." $boldgreen
  else
  cecho "Error: setuptools-0.6c11-py2.7.egg not found!!!download now......"
  wget -c http://pypi.python.org/packages/2.7/s/setuptools/setuptools-0.6c11-py2.7.egg
fi

cecho "Compiling Python..." $boldgreen

tar xvfz Python-${PYTHON_VERSION}.tgz
cd Python-${PYTHON_VERSION}
./configure --prefix=/opt/python${PYTHON_VERSION} --with-threads --enable-shared
make
make install

touch /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf
echo "/opt/python${PYTHON_VERSION}/lib/" >> /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf
ldconfig

ln -sf /opt/python${PYTHON_VERSION}/bin/python /usr/bin/python2.7

cd /svr-setup

sh setuptools-0.6c11-py2.7.egg --prefix=/opt/python${PYTHON_VERSION}

/opt/python${PYTHON_VERSION}/bin/easy_install pip

ln -sf /opt/python${PYTHON_VERSION}/bin/pip /usr/bin/pip
ln -sf /opt/python${PYTHON_VERSION}/bin/virtualenv /usr/bin/virtualenv

echo "alias python=/opt/python${PYTHON_VERSION}/bin/python" >> ~/.bash_profile
echo "alias python2.7=/opt/python${PYTHON_VERSION}/bin/python" >> ~/.bash_profile
echo "PATH=$PATH:/opt/python2.7/bin" >> ~/.bash_profile
source ~/.bash_profile

#cd /opt/python2.7.1/bin
#./easy_install ElementTree
#./easy_install Markdown
#./easy_install html5lib
#./easy_install python-openid

    echo "*************************************************"
    cecho "* Python Update installed " $boldgreen
    echo "*************************************************"
fi
if [ -f $CUR_DIR/Extras/nginx-update.sh ];
then
    chmod +x $CUR_DIR/Extras/nginx-update.sh
fi

echo " "

ASK "Add script shortcuts (as shown in command_shortcuts.txt) ? [y/n] "
if [[ "$key" = [yY] ]];
then
    cecho "**********************************************************************" $boldgreen
    cecho "* Add cmd shortcuts for php.ini, my.cnf, php-fpm.conf, nginx.conf and virtual.conf " $boldgreen
    cecho "* Edit php.ini = phpedit " $boldgreen
    cecho "* Edit my.cnf = mycnf " $boldgreen
    cecho "* Edit php-fpm.conf = fpmconf " $boldgreen
    cecho "* Edit nginx.conf = nginxconf " $boldgreen
    cecho "* Edit virtual.conf = vhostconf " $boldgreen
    cecho "* nginx stop/start/restart = ngxstop/ngxstart/ngxrestart " $boldgreen
    cecho "* php-fpm stop/start/restart = fpmstop/fpmstart/fpmrestart " $boldgreen
    cecho "* mysql stop/start/restart = mysqlstop/mysqlstart/mysqlrestart " $boldgreen
    cecho "* nginx + php-fpm stop/start/restart = npstop/npstart/nprestart " $boldgreen
    cecho "* memcached stop/start/restart = memcachedstop/memcachedstart/memcachedrestart " $boldgreen
    cecho "* csf stop/start/restart = csfstop/csfstart/csfrestart " $boldgreen
    cecho "**********************************************************************" $boldgreen

    echo "nano -w /usr/local/lib/php.ini" > /usr/bin/phpedit ; chmod 700 /usr/bin/phpedit
    echo "nano -w /etc/my.cnf" >/usr/bin/mycnf ; chmod 700 /usr/bin/mycnf
    echo "nano -w /usr/local/etc/php-fpm.conf" >/usr/bin/fpmconf ; chmod 700 /usr/bin/fpmconf
    echo "nano -w /usr/local/nginx/conf/nginx.conf" >/usr/bin/nginxconf ; chmod 700 /usr/bin/nginxconf
    echo "nano -w /usr/local/nginx/conf/conf.d/virtual.conf" >/usr/bin/vhostconf ; chmod 700 /usr/bin/vhostconf
echo "nano -w /usr/local/nginx/conf/php.conf" >/usr/bin/phpinc ; chmod 700 /usr/bin/phpinc
echo "nano -w /usr/local/nginx/conf/drop.conf" >/usr/bin/dropinc ; chmod 700 /usr/bin/dropinc
echo "nano -w /usr/local/nginx/conf/staticfiles.conf" >/usr/bin/statfilesinc ; chmod 700 /usr/bin/statfilesinc

    echo "service nginx stop" >/usr/bin/ngxstop ; chmod 700 /usr/bin/ngxstop
    echo "service nginx start" >/usr/bin/ngxstart ; chmod 700 /usr/bin/ngxstart
    echo "service nginx restart" >/usr/bin/ngxrestart ; chmod 700 /usr/bin/ngxrestart
    echo "service php-fpm stop" >/usr/bin/fpmstop ; chmod 700 /usr/bin/fpmstop
    echo "service php-fpm start" >/usr/bin/fpmstart ; chmod 700 /usr/bin/fpmstart
    echo "service php-fpm restart" >/usr/bin/fpmrestart ; chmod 700 /usr/bin/fpmrestart
    echo "service mysql stop" >/usr/bin/mysqlstop ; chmod 700 /usr/bin/mysqlstop
    echo "service mysql start" >/usr/bin/mysqlstart ; chmod 700 /usr/bin/mysqlstart
    echo "service mysql restart" >/usr/bin/mysqlrestart ; chmod 700 /usr/bin/mysqlrestart
    echo "service nginx stop;service php-fpm stop" >/usr/bin/npstop ; chmod 700 /usr/bin/npstop
    echo "service nginx start;service php-fpm start" >/usr/bin/npstart ; chmod 700 /usr/bin/npstart
    echo "service nginx restart;service php-fpm restart" >/usr/bin/nprestart ; chmod 700 /usr/bin/nprestart
    echo "service memcached stop" >/usr/bin/memcachedstop ; chmod 700 /usr/bin/memcachedstop
    echo "service memcached start" >/usr/bin/memcachedstart ; chmod 700 /usr/bin/memcachedstart
    echo "service memcached restart" >/usr/bin/memcachedrestart ; chmod 700 /usr/bin/memcachedrestart

    echo "service csf stop" >/usr/bin/csfstop ; chmod 700 /usr/bin/csfstop
    echo "service csf start" >/usr/bin/csfstart ; chmod 700 /usr/bin/csfstart
    echo "service csf restart" >/usr/bin/csfrestart ; chmod 700 /usr/bin/csfrestart
fi

echo " "

cecho "**********************************************************************" $boldgreen
cecho "* Starting Services..." $boldgreen
cecho "**********************************************************************" $boldgreen
if [[ "$NSD_INSTALL" = [yY] ]]; 
then
    /etc/init.d/nsd start
fi

if [ -f /etc/init.d/ntpd ];
then
    /etc/init.d/ntpd start
fi

if [[ "$NGINX_INSTALL" = [yY] ]]; 
then
    /etc/init.d/nginx start
fi

if [[ "$MDB_INSTALL" = [yY] ]]; 
then
    /etc/init.d/mysql start
fi

if [[ "$MYSQL_INSTALL" = [yY] ]]; 
then
    /etc/init.d/mysqld start
fi

echo " "

cecho "**********************************************************************" $boldgreen
cecho "* Installation complete, congratulations!" $boldgreen
cecho "* For security reasons we would recommend deleting this script." $boldgreen
cecho "* " $boldgreen
cecho "* We would highly recommend that you reboot your server." $boldgreen
cecho "* " $boldgreen
cecho "* Enjoy CentOS  -  BTCentral" $boldgreen
cecho "**********************************************************************" $boldgreen

cd

ASK "Do would you like to run script cleanup (Highly recommended) ? [y/n] "
if [[ "$key" = [yY] ]];
then
    rm -rf /svr-setup
    rm -rf $CUR_DIR/config
    rm -rf $CUR_DIR/init
    rm -rf $CUR_DIR/sysconfig
    echo "Temporary files/folders removed"
fi

ASK "Do you want to delete this script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Deleting Centmin script... " $boldgreen
    echo "*************************************************"
    echo "Removing..."

rm -f $0

    echo "*************************************************"
    cecho "* Centmin script deleted" $boldgreen
    echo "*************************************************"
fi

    echo "*************************************************"
    cecho "* Running updatedb command. Please wait...." $boldgreen
    echo "*************************************************"

updatedb

exit 0